#ifndef LIST_H
#define LIST_H

#include "Container.h"

// Work around compilers not supporting C++11.
#define override

namespace container {

class Iterator;

// A null-terminated linked list.
class List: public Container{
public:
  // Allows the iterator to access its internals.
  friend class ListIterator;

  virtual Iterator *GetIterator() override;

  // Operation specific to List.
  void Append(Object *aObject);
  void Remove(Object *aObject);

  // Constructor omitted.
  List();
  virtual ~List() {};

private:
  struct Node {
    Object *mItem;
    Node *mNext;
  };

  Node *mHead;
};

class ListIterator: public Iterator {
public:
  virtual void First() override;
  virtual void Next() override;
  virtual Object* GetCurrentItem() override;
  virtual bool IsDone() override;

  ListIterator(List *aContainer);
  virtual ~ListIterator();

private:
  List *mContainer;
  List::Node *mCurrent;
};

} // namespace container

#endif
