#include "DBoxClient.h"

namespace cloud {
namespace dbox {

static const size_t kMaxNameLength = 1024;

void
DBoxFileSystem::Connect(const char* aHost, uint16_t aPort)
{
  // Forward the invocation to vendor implementation.
  ConnectTo(aHost, aPort);
}

bool
DBoxFileSystem::IsConnected()
{
  // Forward the invocation to vendor implementation.
  return IsOnline();
}

void
DBoxFileSystem::Disconnect()
{
  // Forward the invocation to vendor implementation.
  Detach();
}

DBoxFileSystem::~DBoxFileSystem()
{
}

const char*
DBoxFile::GetName() const
{
  // Use qualified name to disambiguate that we are calling the inherited
  // implementation from cloud::dbox::impl::DBoxFileImpl, not making a recursive
  // call to self.
  const char *name = impl::DBoxFileImpl::GetName();

  // XXX Bad sample: the decorator part is mixed with the decorated part.
  if (!IsEncrypted()) {
    return name;
  }

  // Decrypt name
  static char dName[kMaxNameLength];
  size_t outNameLen = 0;
  DecryptBytes(name, dName, &outNameLen);
  // XXX Note that this is not thread-safe.
  return name;
}

void
DBoxFile::Delete()
{
  // The option of purging history is lost in the adaptation.
  Remove(true);
}

DBoxFile::~DBoxFile()
{
}

void DBoxFolder::Delete()
{
  // The option of temporary removal is lost in the adaptation.
  Remove(true);
}

DBoxFolder::~DBoxFolder()
{
}

} // namespace impl
} // namespace cloud

